@@ -143,6 +143,14 @@ KMixWindow::~KMixWindow()
     }
   // -2- Mixer HW
   MixerToolBox::instance()->deinitMixer();
+
+  // GUIProfile cache should be cleared very very late, as GUIProfile instances are used in the Views, which
+  // means main window and potentially also in the tray popup (at least we might do so in the future).
+  // This place here could be to early, if we would start to GUIProfile outside KMixWIndow, e.g. in the tray popup.
+  // Until we do so, this is the best place to call clearCache(). Later, e.g. in main() would likely be problematic.
+  GUIProfile::clearCache();
+
+
 }
 
 
@@ -581,6 +589,11 @@ KMixWindow::loadBaseConfig()
 
 
   GlobalConfig::instance().volumeOverdrive = config.readEntry("VolumeOverdrive", false);
+
+  GlobalConfig::instance().debugControlManager = config.readEntry("Debug.ControlManager", false);
+  GlobalConfig::instance().debugGUI = config.readEntry("Debug.GUI", false);
+  GlobalConfig::instance().debugVolume = config.readEntry("Debug.Volume", false);
+
   // --- Advanced options, without GUI: END -------------------------------------
 
   m_backendFilter = config.readEntry<>("Backends", QList<QString>());
@@ -1075,6 +1088,8 @@ KMixWindow::addMixerWidget(const QString& mixer_ID, QString guiprofId, int inser
   m_dontSetDefaultCardOnStart = false;
 
   kmw->loadConfig(KGlobal::config().data());
+  // Now force to read for new tabs, especially after hotplug. Note: Doing it here is bad design and possibly
+  // obsolete, as the backend should take care of upating itself.
   kmw->mixer()->readSetFromHWforceUpdate();
   return true;
 }
